unit Globes;
(***********************************************************************
 *                                                                     *
 *  Copyright (C) 1996-19..  Erol S. Uzuner                            *
 *                                                                     *
 *  Modul       :       Globes                                         *
 *  Version     :       1.0 (5.8.96)                                   *
 *                                                                     *
 *  Beschreibung:       Definition von globalen Prozeduren             *
 *                                                                     *
 *  Autor       :       Erol S. Uzuner                                 *
 *                                                                     *
 *  Datum       :       Fri Okt 6  20:00:00 1996                       *
 *                                                                     *
 *                                                                     *
 *  Aenderungen :                                                      *
 *  Datum        Autor          Beschreibung
 *
 *                                                                     *
 ***********************************************************************)
interface

uses SysUtils, Dialogs, Forms, Controls, StdCtrls;

function MsgDlg(const Msg: string; AType: TMsgDlgType;
  AButtons: TMsgDlgButtons; DefBtn: TMsgDlgBtn; HelpCtx: Longint): Word;

function isEqualDate(date1, date2 : TDateTime) : boolean;


function IsDate(const DateStr: String) : Boolean;
function IsTime(const TimeStr : String) : Boolean;
function IsDateTime(const DateStr: String) : Boolean;
function IsInt(const int: string; var i : Integer): Boolean;
function IsFloat(const Float: string; var e : Extended): Boolean;
function IsAInt(const int: string): Boolean;
function IsAFloat(const Float: string): Boolean;


implementation

(***********************************************************************
 *                                                                     *
 *  Name        :  MsgDlg                                             *
 *                                                                     *
 *  Beschreibung:  Ein MessageDialog bei dem man den Aktiven Button    *
 *			 whlen kann
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)

function MsgDlg(const Msg: string; AType: TMsgDlgType;
  AButtons: TMsgDlgButtons; DefBtn: TMsgDlgBtn; HelpCtx: Longint): Word;

const BtnNames: array[TMsgDlgBtn] of string = (
    'Yes', 'No', 'OK', 'Cancel', 'Abort', 'Retry', 'Ignore', 'All', 'NoToAll',
    'YesToAll', 'Help');

var
  W: TForm;
  i : Integer;
  OldCursor : TCursor;
begin
  OldCursor := Screen.Cursor;
  Screen.Cursor := crDefault;

  W := CreateMessageDialog(Msg, AType, AButtons);
  try
    for i := 0 to W.ControlCount-1 do
       if W.Controls[i] Is TButton then
           with W.Controls[i] as TButton do
                if name = BtnNames[DefBtn] then
                begin
                   default := true;
                   W.activeControl := TButton(W.Controls[i]);
                end
                else
                    default := false;

    W.HelpContext := HelpCtx;
    W.ScaleBy(Screen.PixelsPerInch, 96);
    Result := W.ShowModal;
  finally
    W.Free;
    Screen.Cursor := OldCursor
  end;
end;


(***********************************************************************
 *                                                                     *
 *  Name        :  isEqualDate                                         *
 *                                                                     *
 *  Beschreibung:   berprfen auf gleiches Datum		       *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)

function isEqualDate(date1, date2 : TDateTime) : boolean;
begin Result := DateTimeToTimeStamp(date1).Date = DateTimeToTimeStamp(date2).Date;
end;


(***********************************************************************
 *                                                                     *
 *  Name        :  IsDate                                              *
 *                                                                     *
 *  Beschreibung:                                                      *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)
function IsDate(const DateStr: String) : Boolean;
begin
   Result := TRUE;
   try
      StrToDate(DateStr);
   except
//      on EConvertError do Result := FALSE;
        on Exception do Result := FALSE;
   end;
end;

(***********************************************************************
 *                                                                     *
 *  Name        :  IsTime                                              *
 *                                                                     *
 *  Beschreibung:                                                      *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)
function IsTime(const TimeStr: String) : Boolean;
begin
   Result := TRUE;
   try
      StrToTime(TimeStr);
   except
//      on EConvertError do Result := FALSE;
        on Exception do Result := FALSE;
   end;
end;

(***********************************************************************
 *                                                                     *
 *  Name        :  IsInt                                               *
 *                                                                     *
 *  Beschreibung:                                                      *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)
function IsInt(const int: string; var i : Integer): Boolean;
var E : Integer;
begin
  Val(int, i, E);
  Result := E = 0;
end;

function IsAInt(const int: string): Boolean;
var E, i : Integer;
begin
  Val(int, i, E);
  Result := E = 0;
end;

(***********************************************************************
 *                                                                     *
 *  Name        :  IsDate                                              *
 *                                                                     *
 *  Beschreibung:                                                      *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)
function IsDateTime(const DateStr: String) : Boolean;
begin
   Result := TRUE;
   try
      StrToDateTime(DateStr);
   except
//      on EConvertError do Result := FALSE;
        on Exception do Result := FALSE;
   end;
end;


(***********************************************************************
 *                                                                     *
 *  Name        :  IsFloat                                             *
 *                                                                     *
 *  Beschreibung:                                                      *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)
function IsFloat(const Float: string; var e : Extended): Boolean;
begin Result := TextToFloat(PChar(Float), e, fvExtended);
end;

function IsAFloat(const Float: string): Boolean;
var e : Extended;
begin Result := TextToFloat(PChar(Float), e, fvExtended);
end;



end.
